function [I,FC_modes,projected_FC_modes,m_star] = f_PCA_identifiability_zscore(orig_matrix,Test_index,Retest_index,configs)

%% Compute Identifiability matrix, original FCs
orig_matrix_test = orig_matrix(:,Test_index);
orig_matrix_retest = orig_matrix(:,Retest_index);   
Ident_mat_orig = corr(orig_matrix_retest,orig_matrix_test); 
%% Idiff computation, original FCs
%% Idiff = <Iself> - <Iothers> (Amico & Go??i, SciRep 2018; i.e. <Main diagonal> - <Triu> of the Identifiability matrix)     
mask_diag = logical(eye(size(Ident_mat_orig)));
% Iself_orig = mean(Ident_mat_orig(mask_diag));
% Iothers_orig = mean(Ident_mat_orig(~mask_diag));
% Idiff_orig = (Iself_orig - Iothers_orig) * 100; % Identifiability score for original connectivity data      
z_test = mean((Ident_mat_orig(mask_diag) - mean(Ident_mat_orig,1)')./std(Ident_mat_orig,0,1)');
z_retest = mean((Ident_mat_orig(mask_diag) - mean(Ident_mat_orig,2))./std(Ident_mat_orig,0,2));
Idiff_orig = (z_test + z_retest)/2;

Iself_recon = zeros(1,configs.max_numPCs);
Iother_recon = zeros(1,configs.max_numPCs);
Idiff_recon = zeros(1,configs.max_numPCs); %Initialization for Identifiability score for reconstructed connectivty data (indexed by number of components).


%% Differential Identifiability (Idiff) evaluation of PCA decomposition into FC-modes (see also Fig.2 of Amico & Go??i, SciRep 2018)
PCA_comps_range = 2:configs.max_numPCs; % Note that at least 2 PCA components are needed for Idiff evaluation
[FC_modes, projected_FC_modes,latent] = pca(orig_matrix,'NumComponents',configs.max_numPCs);   
R2 = cumsum(latent)./sum(latent);

for i= PCA_comps_range
    recon_matrix = projected_FC_modes(:,1:i) * FC_modes(:,1:i)'; % PCA reconstructed demeaned data    
    recon_matrix = bsxfun(@plus, recon_matrix,mean(orig_matrix)); % plug the mean back
    recon_matrix_test = recon_matrix(:,Test_index);
    recon_matrix_retest = recon_matrix(:,Retest_index);
    %% Compute Identifiability matrix, reconstructed FCs
    Ident_mat_recon = corr(recon_matrix_retest,recon_matrix_test);
    % Ident_mat_recon = pdist2(recon_matrix_retest',recon_matrix_test','minkowski',1);
    %% Idiff computation, reconstructed FCs
    %% Idiff = <Iself> - <Iothers> (Amico & Go??i, SciRep 2018; i.e. <Main diagonal> - <Triu> of the Identifiability matrix)       
    Iself_recon(i) = mean(Ident_mat_recon(mask_diag));
    Iothers_recon(i) = mean(Ident_mat_recon(~mask_diag));
    % Idiff_recon(i) = (Iself_recon - Iothers_recon) * 100;
    
    z_test = mean((Ident_mat_recon(mask_diag) - mean(Ident_mat_recon,1)')./std(Ident_mat_recon,0,1)');
    z_retest = mean((Ident_mat_recon(mask_diag) - mean(Ident_mat_recon,2))./std(Ident_mat_recon,0,2));
    Idiff_recon(i) = (z_test + z_retest)/2;
end

%% Identifiability matrix at optimal reconstruction (see also Fig 3C1 in Amico & Go??i, SciRep 2018)
Idiff_opt = max(Idiff_recon);
m_star = PCA_comps_range(Idiff_recon(2:end)==Idiff_opt); % obtain the optimal number of PCA components for reconstruction. First point is intentionally skipped since range of components starts on 2.
recon_matrix_opt = projected_FC_modes(:,1:m_star) * FC_modes(:,1:m_star)'; % PCA reconstructed demeaned data    
recon_matrix_opt = bsxfun(@plus, recon_matrix_opt,mean(orig_matrix)); % plug the mean back
recon_matrix_opt_test = recon_matrix_opt(:,Test_index);
recon_matrix_opt_retest = recon_matrix_opt(:,Retest_index);
%% Compute Recon Identifiability matrix at optimal point
Ident_mat_recon_opt = corr(recon_matrix_opt_retest,recon_matrix_opt_test);
m_star = find(Idiff_recon == max(Idiff_recon));

%% Save Identifiability Results in Struct
I.self = Iself_recon;
I.others = Iothers_recon;
I.diff = Idiff_recon;
I.R2 = R2;
I.I_matrix(:,:,1) = Ident_mat_orig;
I.I_matrix(:,:,2) = Ident_mat_recon_opt;