function [sig_RSNs_over,sig_RSNs_under] = f_evaluate_RSN(mask,alpha,mask_str,output_dir)

%Load Masks
load('RSN_mask.mat');
load('ShenInfo.mat');
numROIs = size(mask_RSNs,1);
numRSNs = size(mask_RSNs,3);
utri_mask = triu(true(numROIs,numROIs),1);
    
%Put mask in 2D format 
mask_temp = zeros(numROIs,numROIs);
mask_temp(utri_mask) = mask;
mask_temp = mask_temp + mask_temp';
    
%Count number of over represented RSNs per mask
for RSN = 1:size(mask_RSNs,3)
    mask_RSN_temp = mask_RSNs(:,:,RSN);
    count_RSN_temp = nnz(mask_temp(mask_RSN_temp));
    count_RSN(RSN) = count_RSN_temp;
    num_outcomes = sum(sum(mask_temp))/2;
    p_RSN(RSN) = myBinomTest(count_RSN_temp,num_outcomes,prob_RSN_null(RSN),'two');
end

%Calc number of expected edges given size of mask
count_RSN_null_curr = prob_RSN_null.*(sum(sum(mask_RSN_temp))/2);

%Find Over & underrepresented masks Masks
h_RSN = p_RSN < alpha;
h_RSN_over = h_RSN & (count_RSN > count_RSN_null_curr);
h_RSN_under = h_RSN & (count_RSN < count_RSN_null_curr);
num_sig_RSNs = sum(h_RSN,2);

sig_RSNs_over = RSN_str(h_RSN_over);
sig_RSNs_under = RSN_str(h_RSN_under);

%Make & Write out files for BrainNet Viewer
RSNs_use = h_RSN_over;
sig_mask_temp = logical(sum(mask_RSNs(:,:,RSNs_use),3));
mask_temp(~sig_mask_temp) = 0;
nodeDegree = sum(mask_temp)';

nodeDegree = table(nodeDegree,'VariableNames',{'Degree'});
nodeFile_overRepresented_temp = [NodeFileTbl_coordsxinverse(:,1:end-1),nodeDegree,ShenROIdescription1(:,4)];
node_fileName_overRepresented_temp = fullfile(output_dir,strcat('nodeOverRepresented_',mask_str,'.txt'));
node_fileName_overRepresented = fullfile(output_dir,strcat('nodeOverRepresented_',mask_str,'.node'));
writetable(nodeFile_overRepresented_temp,node_fileName_overRepresented_temp,'WriteVariableNames',false,'Delimiter','\t');
movefile(node_fileName_overRepresented_temp,node_fileName_overRepresented);

%Write Edge Text File
edge_fileName_overRepresented_temp = fullfile(output_dir,strcat('edgeOverRepresented_',mask_str,'.txt'));
edge_fileName_overRepresented = fullfile(output_dir,strcat('edgeOverRepresented_',mask_str,'.edge'));
dlmwrite(edge_fileName_overRepresented_temp,mask_temp,'delimiter','\t');
copyfile(edge_fileName_overRepresented_temp,edge_fileName_overRepresented);

